ExUtcp.Search.Security (ex_utcp v0.3.2)

Copy Markdown View Source

Security scanning for search results using TruffleHog.

Scans tool definitions and provider configurations for sensitive data and provides warnings or filtering capabilities.

Summary

Functions

Adds security warnings to search results.

Filters search results to exclude tools with sensitive data warnings.

Checks if a search result contains sensitive data.

Scans a single provider for sensitive data.

Scans providers for sensitive data.

Scans a single tool for sensitive data.

Scans tools for sensitive data and returns security warnings.

Functions

add_security_warnings(search_results)

@spec add_security_warnings([map()]) :: [map()]

Adds security warnings to search results.

filter_secure_results(search_results)

@spec filter_secure_results([map()]) :: [map()]

Filters search results to exclude tools with sensitive data warnings.

has_sensitive_data?(search_result)

@spec has_sensitive_data?(map()) :: boolean()

Checks if a search result contains sensitive data.

scan_provider(provider)

@spec scan_provider(map()) :: [map()]

Scans a single provider for sensitive data.

scan_providers(providers)

@spec scan_providers([map()]) :: %{required(String.t()) => [map()]}

Scans providers for sensitive data.

scan_tool(tool)

@spec scan_tool(ExUtcp.Types.tool()) :: [map()]

Scans a single tool for sensitive data.

scan_tools(tools)

@spec scan_tools([ExUtcp.Types.tool()]) :: %{required(String.t()) => [map()]}

Scans tools for sensitive data and returns security warnings.