CLI transport implementation for UTCP.
This transport handles command-line based tool providers, executing external commands to discover and call tools.
Summary
Functions
Creates a new CLI transport.
CLI transport implementation for UTCP.
This transport handles command-line based tool providers, executing external commands to discover and call tools.
Creates a new CLI transport.