Manages a pool of GraphQL connections with lifecycle management.
Summary
Functions
Returns a specification to start this module under a supervisor.
Closes all connections.
Closes a specific connection.
Gets or creates a connection for the given provider.
Returns a connection to the pool.
Starts the connection pool.
Gets pool statistics.
Types
Functions
Returns a specification to start this module under a supervisor.
See Supervisor.
@spec close_all_connections() :: :ok
Closes all connections.
@spec close_connection(pid()) :: :ok
Closes a specific connection.
Gets or creates a connection for the given provider.
@spec return_connection(pid()) :: :ok
Returns a connection to the pool.
Starts the connection pool.
@spec stats() :: map()
Gets pool statistics.