Testable module for TCP/UDP transport to enable mocking in tests.
This module provides a way to inject mocks for the TCP/UDP transport components during testing, allowing for isolated unit tests.
Summary
Functions
Clears all mocks.
Creates a mock connection for testing.
Creates a mock pool for testing.
Creates a test TCP provider.
Creates a test tool.
Creates a test UDP provider.
Gets the mock module for connections.
Gets the mock module for pools.
Mocks a connection error.
Mocks a pool error.
Mocks a tool call response.
Mocks a tool stream response.
Sets the mock modules for testing.
Validates a TCP provider configuration.
Validates a UDP provider configuration.
Functions
Clears all mocks.
Creates a mock connection for testing.
Creates a mock pool for testing.
Creates a test TCP provider.
Creates a test tool.
Creates a test UDP provider.
Gets the mock module for connections.
Gets the mock module for pools.
Mocks a connection error.
Mocks a pool error.
Mocks a tool call response.
Mocks a tool stream response.
Sets the mock modules for testing.
Validates a TCP provider configuration.
Validates a UDP provider configuration.